@@ -31,21 +31,22 @@ It doesn't support:
 
 """
 from __future__ import annotations
+
+import asyncio
 import copy
 import datetime
 import enum
 import logging
-import asyncio
+from typing import TYPE_CHECKING, Iterable, MutableSequence, Sequence, Union
 
 import piaf.comm
 import piaf.comm.mts
 import piaf.exceptions as ex
-
-from typing import Sequence, Union, Iterable, MutableSequence, TYPE_CHECKING
+from piaf.audit import AGENTS_PARENT_TOPIC, Event, Topic
 
 if TYPE_CHECKING:
     import piaf.behavior
-    import piaf.platform
+    import piaf.ptf
 
 __all__ = ["Agent", "AgentState"]
 
@@ -107,7 +108,7 @@ class Agent:
     .. code-block:: python
 
         from piaf.agent import Agent
-        from piaf.launcher import Agentdescription, PlatformLauncher
+        from piaf.launcher import AgentDescription, PlatformLauncher
         from piaf.comm.mts import MemoryMessageTransferHandler
 
         class MyAgent(Agent):
@@ -146,13 +147,13 @@ class Agent:
     def __init__(
         self,
         aid: piaf.comm.AID,
-        platform: piaf.platform.AgentPlatformFacade | piaf.platform.AgentPlatform,
+        platform: piaf.ptf.AgentPlatformFacade,
     ):
         """
         Create a new Agent with the provided information.
 
         :param aid: this agent's identifier
-        :param platform: the platform (or a facade) where this agent is deployed
+        :param platform: the platform facade that proxies the platform where this agent is deployed
         """
         self.logger = logging.getLogger(type(self).__name__)
         self._aid = copy.deepcopy(aid)
@@ -327,6 +328,15 @@ class Agent:
 
         self._platform.send(piaf.comm.Message(envelope, message))
 
+        # Fire event
+        msg: piaf.comm.ACLMessage = copy.deepcopy(message)
+        self._platform.evt_manager.publish_sync(
+            Event(self.aid.name, "message_sending", msg),
+            Topic.resolve_from_parent_topic(
+                AGENTS_PARENT_TOPIC, f"{self.aid.short_name}.messages"
+            ),
+        )
+
     def _running(self) -> bool:
         return (
             self.state == AgentState.ACTIVE
