@@ -2,7 +2,7 @@
 """
 This module contains every related to the Message Transport System.
 
-The MTS is seperated in different components:
+The MTS is separated in different components:
 
 * :class:`MessageTransferHandler`, which are components designed to handle
   communication using a specific protocol
@@ -15,37 +15,37 @@ you to create your own components (and thus use your own transport protocol or p
 representation).
 """
 from __future__ import annotations
+
 import abc
-from asyncio.futures import Future
-from datetime import datetime
-import logging
+import asyncio
 import copy
 import itertools
-import asyncio
+import logging
 import urllib.parse
-
-from piaf.comm import Envelope, Message, ReceivedObject, AID
-from piaf.util import failure_message_from_request
-import piaf.exceptions as ex
-import piaf.comm
-
+from asyncio.futures import Future
+from datetime import datetime
 from typing import (
+    TYPE_CHECKING,
+    Any,
     ClassVar,
     Dict,
     Iterable,
     List,
     NamedTuple,
+    Optional,
     Sequence,
     Tuple,
     Type,
-    Any,
-    Optional,
     Union,
-    TYPE_CHECKING,
 )
 
+import piaf.comm
+import piaf.exceptions as ex
+from piaf.comm import AID, ACLMessage, Envelope, Message, Performative, ReceivedObject
+from piaf.audit import ACC_TOPIC, AGENTS_PARENT_TOPIC, Event, Topic
+
 if TYPE_CHECKING:
-    from piaf.platform import AgentPlatform
+    from piaf.ptf import AgentPlatform
 
 from piaf.exceptions import DuplicatedNameException
 
@@ -73,7 +73,7 @@ class MailBox:
         Retrieve the first matching message in the mail box.
 
         This method blocks until such message is inserted with the method :meth:`put`.
-        Note that the mesage is removed from the queue so two successive calls to
+        Note that the message is removed from the queue so two successive calls to
         :meth:`get` (or :meth:`get_nowait`) will end up with two different messages.
         Template is applied on the :class:`ACLMessage`.
         """
@@ -92,7 +92,7 @@ class MailBox:
         Lookup the queue for a message matching the provided template.
 
         If no such message exists, this method will return ``None``. This method
-        doesn't take the lock so callers must lock the call themself.
+        doesn't take the lock so callers must lock the call themselves.
         Template is applied on the :class:`ACLMessage`.
         """
         for i in range(len(self._queue)):
@@ -126,13 +126,13 @@ class MailBoxDelegate:
     Restrict access to agent/service mailbox. Only exposed method is :meth:`MailBox.put`.
     """
 
-    def __init__(self, delegate: piaf.comm.mts.Mailbox) -> None:
+    def __init__(self, delegate: MailBox) -> None:
         """
         Create a new :class:`MailBoxDelegate` object.
 
         :param delegate: agent's mailbox
         """
-        self._delegate: piaf.comm.mts.MailBox = delegate
+        self._delegate: MailBox = delegate
 
     async def put(self, item: piaf.comm.Message) -> None:
         """Put the provided message in this mailbox."""
@@ -177,7 +177,7 @@ class PlayloadParser(metaclass=abc.ABCMeta):
 
 class AgentCommunicationChannel:
     """
-    :class:`AgentCommunicationChannel` is an entity providing the mesaaging service to the AP agents.
+    :class:`AgentCommunicationChannel` is an entity providing the messaging service to the AP agents.
 
     See http://fipa.org/specs/fipa00067/ for more information.
     """
@@ -248,6 +248,10 @@ class AgentCommunicationChannel:
         mtp.acc = self
         await mtp.start()
 
+        await self._ptf.evt_manager.publish(
+            Event("acc", "mtp_registration", mtp.scheme), ACC_TOPIC
+        )
+
     @property
     def addresses(self) -> Tuple[str, ...]:
         """Get all addresses this ACC can be contacted with."""
@@ -266,7 +270,7 @@ class AgentCommunicationChannel:
         """
         Stop the ACC.
 
-        This will cancel all running tasks and stop all runing MTPs.
+        This will cancel all running tasks and stop all running MTPs.
         """
         for task in self._tasks:
             task.cancel()
@@ -363,7 +367,7 @@ class AgentCommunicationChannel:
             if success:
                 break
 
-        # If still not successfull, try name resolution
+        # If still not successful, try name resolution
         # Not implemented yet
         if not success:
             pass
@@ -381,6 +385,15 @@ class AgentCommunicationChannel:
         """
         if aid.short_name in self._knows:
             await self._knows[aid.short_name].put(msg)
+
+            # Fire msg reception event
+            acl_msg: ACLMessage = copy.deepcopy(msg.acl_message)
+            await self._ptf.evt_manager.publish(
+                Event(aid.name, "message_reception", acl_msg),
+                Topic.resolve_from_parent_topic(
+                    AGENTS_PARENT_TOPIC, f"{aid.short_name}.messages"
+                ),
+            )
         else:
             await self._send_failure_message(msg)
 
@@ -422,8 +435,13 @@ class AgentCommunicationChannel:
         """
 
         try:
-            reply_msg = failure_message_from_request(
-                msg.acl_message, f"Unreachable agent: {msg.acl_message.receiver}"
+            reply_msg = (
+                ACLMessage.Builder()
+                .performative(Performative.FAILURE)
+                .receiver(msg.acl_message.sender)
+                .conversation_id(msg.acl_message.conversation_id)
+                .content([msg.acl_message.content, f"Unreachable agent: {msg.acl_message.receiver}"])
+                .build()
             )
             reply_msg.in_reply_to = msg.acl_message.reply_with
 
